@@ -26,6 +26,7 @@
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-bindings.h>
 
+#include "capplet-util.h"
 #include "theme-util.h"
 
 gboolean
@@ -249,7 +250,7 @@ theme_install_file (GtkWindow *parent, const gchar *path)
 			GTK_MESSAGE_ERROR,
 			GTK_BUTTONS_OK,
 			_("Could not install theme engine"));
-    gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), error->message);
+    gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), "%s", error->message);
 
     gtk_dialog_run (GTK_DIALOG (dialog));
     gtk_widget_destroy (dialog);
