@@ -50,7 +50,6 @@ struct App
     GtkWidget	   *refresh_combo;
     GtkWidget	   *rotation_combo;
     GtkWidget	   *panel_checkbox;
-    GtkWidget	   *panel_label;
     GtkWidget	   *clone_checkbox;
     GtkWidget	   *show_icon_checkbox;
 
@@ -62,25 +61,20 @@ struct App
 static void rebuild_gui (App *app);
 static void on_rate_changed (GtkComboBox *box, gpointer data);
 
-#if 0
 static void
-show_error (const GError *err)
+show_error (const char *err)
 {
-    if (!err)
-	return;
-
     GtkWidget *dialog = gtk_message_dialog_new (
 	NULL,
 	GTK_DIALOG_DESTROY_WITH_PARENT,
 	GTK_MESSAGE_WARNING,
-	GTK_BUTTONS_OK, err->message);
+	GTK_BUTTONS_OK, "%s", err);
 
     gtk_window_set_title (GTK_WINDOW (dialog), "");
 
     gtk_dialog_run (GTK_DIALOG (dialog));
     gtk_widget_destroy (dialog);
 }
-#endif
 
 static gboolean
 do_free (gpointer data)
@@ -264,16 +258,14 @@ add_key (GtkWidget *widget,
     if (!info.found)
     {
 	GtkTreeIter iter;
-	gtk_list_store_append (store, &iter);
-
-	gtk_list_store_set (store, &iter,
-			    0, text,
-			    1, width,
-			    2, height,
-			    3, rate,
-			    4, width * height,
-			    5, rotation,
-			    -1);
+	gtk_list_store_insert_with_values (store, &iter, -1,
+                                           0, text,
+                                           1, width,
+                                           2, height,
+                                           3, rate,
+                                           4, width * height,
+                                           5, rotation,
+                                           -1);
 
 	retval = TRUE;
     }
@@ -302,80 +294,6 @@ combo_select (GtkWidget *widget, const char *text)
     return TRUE;
 }
 
-static gboolean
-has_similar_mode (GnomeRROutput *output, GnomeRRMode *mode)
-{
-    int i;
-    GnomeRRMode **modes = gnome_rr_output_list_modes (output);
-    int width = gnome_rr_mode_get_width (mode);
-    int height = gnome_rr_mode_get_height (mode);
-
-    for (i = 0; modes[i] != NULL; ++i)
-    {
-	GnomeRRMode *m = modes[i];
-
-	if (gnome_rr_mode_get_width (m) == width	&&
-	    gnome_rr_mode_get_height (m) == height)
-	{
-	    return TRUE;
-	}
-    }
-
-    return FALSE;
-}
-
-static GnomeRRMode **
-list_clone_modes (GnomeRRConfig *config, GnomeRRScreen *screen)
-{
-    int i;
-    GPtrArray *result;
-    GnomeRRMode **modes;
-
-    for (i = 0; config->outputs[i] != NULL; ++i)
-    {
-	if (config->outputs[i]->connected)
-	{
-	    GnomeRROutput *output =
-		gnome_rr_screen_get_output_by_name (screen, config->outputs[i]->name);
-
-	    modes = gnome_rr_output_list_modes (output);
-	}
-    }
-
-    if (!modes)
-	return NULL;
-
-    result = g_ptr_array_new ();
-
-    for (i = 0; modes[i] != NULL; ++i)
-    {
-	gboolean valid = TRUE;
-	int j;
-
-	for (j = 0; config->outputs[j] != NULL; ++j)
-	{
-	    if (config->outputs[j]->connected)
-	    {
-		GnomeRROutput *output = gnome_rr_screen_get_output_by_name (
-		    screen, config->outputs[j]->name);
-
-		if (!has_similar_mode (output, modes[i]))
-		{
-		    valid = FALSE;
-		    break;
-		}
-	    }
-	}
-
-	if (valid)
-	    g_ptr_array_add (result, modes[i]);
-    }
-
-    g_ptr_array_add (result, NULL);
-
-    return (GnomeRRMode **)g_ptr_array_free (result, FALSE);
-}
-
 static GnomeRRMode **
 get_current_modes (App *app)
 {
@@ -383,7 +301,7 @@ get_current_modes (App *app)
 
     if (app->current_configuration->clone)
     {
-	return list_clone_modes (app->current_configuration, app->screen);
+	return gnome_rr_screen_list_clone_modes (app->screen);
     }
     else
     {
@@ -450,8 +368,6 @@ rebuild_rotation_combo (App *app)
 	combo_select (app->rotation_combo, N_("Normal"));
 }
 
-#define idle_free_printf(x) idle_free (g_strdup_printf (x))
-
 static void
 rebuild_rate_combo (App *app)
 {
@@ -512,6 +428,7 @@ count_active_outputs (App *app)
     return count;
 }
 
+#if 0
 static int
 count_all_outputs (GnomeRRConfig *config)
 {
@@ -522,6 +439,7 @@ count_all_outputs (GnomeRRConfig *config)
 
     return i;
 }
+#endif
 
 static void
 rebuild_resolution_combo (App *app)
@@ -1411,7 +1329,7 @@ paint_output (App *app, cairo_t *cr, int i)
     }
     else if (output->rotation & GNOME_RR_ROTATION_90)
     {
-	angle = G_PI / 2;
+	angle = 1.5 * G_PI;
     }
     else if (output->rotation & GNOME_RR_ROTATION_180)
     {
@@ -1419,7 +1337,7 @@ paint_output (App *app, cairo_t *cr, int i)
     }
     else if (output->rotation & GNOME_RR_ROTATION_270)
     {
-	angle = 1.5 * G_PI;
+	angle = G_PI / 2;
     }
     else
     {
@@ -1663,6 +1581,7 @@ apply (App *app)
     }
 }
 
+#if 0
 /* Returns whether the graphics driver doesn't advertise RANDR 1.2 features, and just 1.0 */
 static gboolean
 driver_is_randr_10 (GnomeRRConfig *config)
@@ -1683,6 +1602,7 @@ driver_is_randr_10 (GnomeRRConfig *config)
 
     return (count_all_outputs (config) == 1 && strcmp (config->outputs[0]->name, "default") == 0);
 }
+#endif
 
 static void
 on_detect_displays (GtkWidget *widget, gpointer data)
@@ -1726,7 +1646,8 @@ run_application (App *app)
 				       on_screen_changed, app);
     if (!app->screen)
     {
-	g_error ("Could not get screen info");
+	g_warning (_("The X server does not support the XRANDR extension.  Runtime resolution changes to the display size are not available."));
+	show_error (_("The X server does not support the XRANDR extension.  Runtime resolution changes to the display size are not available."));
 	g_object_unref (xml);
 	return;
     }
@@ -1766,7 +1687,6 @@ run_application (App *app)
     g_signal_connect (app->show_icon_checkbox, "toggled", G_CALLBACK (on_show_icon_toggled), app);
 
     app->panel_checkbox = glade_xml_get_widget (xml, "panel_checkbox");
-    app->panel_label = glade_xml_get_widget (xml, "panel_label");
 
     make_text_combo (app->resolution_combo, 4);
     make_text_combo (app->refresh_combo, 3);
@@ -1792,10 +1712,7 @@ run_application (App *app)
     gtk_container_add (GTK_CONTAINER (align), app->area);
 
     on_screen_changed (app->screen, app);
-    rebuild_gui (app);
 
-    gtk_widget_hide (app->panel_checkbox);
-    gtk_widget_hide (app->panel_label);
     g_object_unref (xml);
 
 restart:
