@@ -25,7 +25,7 @@
 #  include <config.h>
 #endif
 
-#include <gnome.h>
+#include <glib/gi18n.h>
 #include <gconf/gconf-client.h>
 
 #include <gdk/gdkx.h>
@@ -1138,32 +1138,11 @@ setup_dialog (GladeXML *dialog, GConfChangeSet *changeset)
 	setup_sound_theme_custom (dialog, CheckXKB());
 }
 
-/* get_legacy_settings
- *
- * Retrieve older gnome_config -style settings and store them in the
- * configuration database.
- *
- * In most cases, it's best to use the COPY_FROM_LEGACY macro defined in
- * capplets/common/capplet-util.h.
- */
-
-static void
-get_legacy_settings (void)
-{
-	GConfClient *client;
-	gboolean val_bool, def;
-
-	client = gconf_client_get_default ();
-	COPY_FROM_LEGACY (bool, "/desktop/gnome/sound/event_sounds", "/sound/system/settings/event_sounds=false");
-	g_object_unref (G_OBJECT (client));
-}
-
 static void
 dialog_response_cb (GtkWidget *dialog, gint response_id, GConfChangeSet *changeset)
 {
 	if (response_id == GTK_RESPONSE_HELP) {
 		capplet_help (GTK_WINDOW (dialog),
-			"user-guide.xml",
 			"goscustmulti-2");
 		return;
 	}
@@ -1176,40 +1155,26 @@ main (int argc, char **argv)
 {
 	GConfChangeSet *changeset;
 	GladeXML       *dialog;
-	GnomeProgram   *program;
  	GOptionContext *context;
 	gboolean apply_only = FALSE;
-	gboolean get_legacy = FALSE;
  	GOptionEntry cap_options[] = {
  		{ "apply", 0, 0, G_OPTION_ARG_NONE, &apply_only,
 		  N_("Just apply settings and quit (compatibility only; now handled by daemon)"), NULL },
 		{ "init-session-settings", 0, 0, G_OPTION_ARG_NONE, &apply_only,
 		  N_("Just apply settings and quit (compatibility only; now handled by daemon)"), NULL },
- 		{ "get-legacy", 0, 0, G_OPTION_ARG_NONE, &get_legacy,
-		  N_("Retrieve and store legacy settings"), NULL },
  		{ NULL }
 	};
 
-	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
-	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-	textdomain (GETTEXT_PACKAGE);
-
         /* Since gstreamer and gnome-vfs require threads, we
          * have to initialise threads here as the first call to glib.
          */
         g_thread_init (NULL);
 
  	context = g_option_context_new (N_("- GNOME Sound Preferences"));
-#if GLIB_CHECK_VERSION (2, 12, 0)
-        g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
-#endif
  	g_option_context_add_main_entries (context, cap_options, GETTEXT_PACKAGE);
 	g_option_context_add_group (context, gst_init_get_option_group ());
 
-	program = gnome_program_init ("gnome-sound-properties", VERSION,
-				      LIBGNOMEUI_MODULE, argc, argv,
- 			    	      GNOME_PARAM_GOPTION_CONTEXT, context,
-				      NULL);
+	capplet_init (context, &argc, &argv);
 
 	activate_settings_daemon ();
 
@@ -1217,30 +1182,25 @@ main (int argc, char **argv)
 	gconf_client_add_dir (gconf_client, "/desktop/gnome/sound", GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
 	gconf_client_add_dir (gconf_client, "/apps/metacity/general", GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
 
-	if (get_legacy) {
-		get_legacy_settings ();
-	} else {
-		dialog = create_dialog ();
-
-		if (dialog) {
-			changeset = gconf_change_set_new ();
-			setup_dialog (dialog, changeset);
-			setup_devices ();
-
-			dialog_win = WID ("sound_prefs_dialog");
-			g_signal_connect (dialog_win, "response", G_CALLBACK (dialog_response_cb), changeset);
-			g_signal_connect (dialog_win, "destroy", G_CALLBACK (gtk_main_quit), NULL);
-			capplet_set_icon (dialog_win, "gnome-sound-properties");
-			gtk_widget_show (dialog_win);
-
-			gtk_main ();
-			gconf_change_set_unref (changeset);
-			g_object_unref (dialog);
-		}
+	dialog = create_dialog ();
+	
+	if (dialog) {
+		changeset = gconf_change_set_new ();
+		setup_dialog (dialog, changeset);
+		setup_devices ();
+		
+		dialog_win = WID ("sound_prefs_dialog");
+		g_signal_connect (dialog_win, "response", G_CALLBACK (dialog_response_cb), changeset);
+		g_signal_connect (dialog_win, "destroy", G_CALLBACK (gtk_main_quit), NULL);
+		capplet_set_icon (dialog_win, "gnome-sound-properties");
+		gtk_widget_show (dialog_win);
+		
+		gtk_main ();
+		gconf_change_set_unref (changeset);
+		g_object_unref (dialog);
 	}
 
 	g_object_unref (gconf_client);
-	g_object_unref (program);
 
 	return 0;
 }
